summaryrefslogtreecommitdiffstats
path: root/kpilot/conduits/knotes/knotes-action.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/conduits/knotes/knotes-action.cc')
-rw-r--r--kpilot/conduits/knotes/knotes-action.cc58
1 files changed, 29 insertions, 29 deletions
diff --git a/kpilot/conduits/knotes/knotes-action.cc b/kpilot/conduits/knotes/knotes-action.cc
index 905e5ef3..ca329132 100644
--- a/kpilot/conduits/knotes/knotes-action.cc
+++ b/kpilot/conduits/knotes/knotes-action.cc
@@ -29,8 +29,8 @@
#include "options.h"
-#include <qmap.h>
-#include <qtimer.h>
+#include <tqmap.h>
+#include <tqtimer.h>
#include <kapplication.h>
@@ -63,8 +63,8 @@ unsigned long version_conduit_knotes = Pilot::PLUGIN_API;
}
-typedef QString KNoteID_t;
-typedef const QString &KNoteID_pt;
+typedef TQString KNoteID_t;
+typedef const TQString &KNoteID_pt;
class NoteAndMemo
{
@@ -79,21 +79,21 @@ public:
int memo() const { return memoId; } ;
KNoteID_t note() const { return noteId; } ;
inline bool valid() const { return (memoId>0) && (!noteId.isEmpty()) ; } ;
- QString toString() const { return CSL1("<%1,%2>").arg(noteId).arg(memoId); } ;
+ TQString toString() const { return CSL1("<%1,%2>").arg(noteId).arg(memoId); } ;
- static NoteAndMemo findNote(const QValueList<NoteAndMemo> &,KNoteID_pt note);
- static NoteAndMemo findMemo(const QValueList<NoteAndMemo> &,int memo);
+ static NoteAndMemo findNote(const TQValueList<NoteAndMemo> &,KNoteID_pt note);
+ static NoteAndMemo findMemo(const TQValueList<NoteAndMemo> &,int memo);
protected:
KNoteID_t noteId;
int memoId;
} ;
-NoteAndMemo NoteAndMemo::findNote(const QValueList<NoteAndMemo> &l ,KNoteID_pt note)
+NoteAndMemo NoteAndMemo::findNote(const TQValueList<NoteAndMemo> &l ,KNoteID_pt note)
{
FUNCTIONSETUP;
- for (QValueList<NoteAndMemo>::ConstIterator it = l.begin();
+ for (TQValueList<NoteAndMemo>::ConstIterator it = l.begin();
it != l.end();
++it)
{
@@ -103,11 +103,11 @@ NoteAndMemo NoteAndMemo::findNote(const QValueList<NoteAndMemo> &l ,KNoteID_pt n
return NoteAndMemo();
}
-NoteAndMemo NoteAndMemo::findMemo(const QValueList<NoteAndMemo> &l , int memo)
+NoteAndMemo NoteAndMemo::findMemo(const TQValueList<NoteAndMemo> &l , int memo)
{
FUNCTIONSETUP;
- for (QValueList<NoteAndMemo>::ConstIterator it =l.begin();
+ for (TQValueList<NoteAndMemo>::ConstIterator it =l.begin();
it != l.end();
++it)
{
@@ -158,7 +158,7 @@ public:
//KNotesIface_stub *fKNotes;
// The timer for invoking process() to do some more work.
- QTimer *fTimer;
+ TQTimer *fTimer;
// The database we're working with (MemoDB)
// PilotSerialDatabase *fDatabase;
@@ -175,7 +175,7 @@ public:
// We need to translate between the ids that KNotes uses and
// Pilot id's, so we make a list of pairs.
//
- QValueList<NoteAndMemo> fIdList;
+ TQValueList<NoteAndMemo> fIdList;
// Setting to delete a KNote when the corresponding memo
// has been deleted.
@@ -185,7 +185,7 @@ public:
KNotesAction::KNotesAction(KPilotLink *o,
- const char *n, const QStringList &a) :
+ const char *n, const TQStringList &a) :
ConduitAction(o,n ? n : "knotes-conduit",a),
fP(new KNotesActionPrivate)
{
@@ -220,7 +220,7 @@ KNotesAction::KNotesAction(KPilotLink *o,
return true;
}
- QString e;
+ TQString e;
if (!openKNotesResource()) return false;
// Database names seem to be latin1
@@ -233,13 +233,13 @@ KNotesAction::KNotesAction(KPilotLink *o,
return false;
}
- fP->fTimer = new QTimer(this);
+ fP->fTimer = new TQTimer(this);
fActionStatus = Init;
// this is not needed. As it is done in the initstate in process();
// resetIndexes();
- connect(fP->fTimer,SIGNAL(timeout()),SLOT(process()));
+ connect(fP->fTimer,TQT_SIGNAL(timeout()),TQT_SLOT(process()));
fP->fTimer->start(0,false);
return true;
@@ -257,7 +257,7 @@ bool KNotesAction::openKNotesResource()
KConfig korgcfg( locate( "config", CSL1("korganizerrc") ) );
korgcfg.setGroup( "Time & Date" );
- QString tz(korgcfg.readEntry( "TimeZoneId" ) );
+ TQString tz(korgcfg.readEntry( "TimeZoneId" ) );
fP->fNotesResource = new KCal::CalendarLocal(tz);
KURL mURL = KGlobal::dirs()->saveLocation( "data", "knotes/" ) + "notes.ics";
@@ -395,8 +395,8 @@ void KNotesAction::getConfigInfo()
fP->fDeleteNoteForMemo = KNotesConduitSettings::deleteNoteForMemo();
- QValueList<KNoteID_t> notes;
- QValueList<int> memos;
+ TQValueList<KNoteID_t> notes;
+ TQValueList<int> memos;
// Make this match the type of KNoteID_t !
notes=KNotesConduitSettings::noteIds();
@@ -416,8 +416,8 @@ void KNotesAction::getConfigInfo()
setFirstSync( true );
}
- QValueList<KNoteID_t>::ConstIterator iNotes = notes.begin();
- QValueList<int>::ConstIterator iMemos = memos.begin();
+ TQValueList<KNoteID_t>::ConstIterator iNotes = notes.begin();
+ TQValueList<int>::ConstIterator iMemos = memos.begin();
while((iNotes != notes.end()) && (iMemos != memos.end()))
{
@@ -465,7 +465,7 @@ bool KNotesAction::modifyNoteOnPilot()
if (nm.valid())
{
- QString text,title,body;
+ TQString text,title,body;
title = fP->fIndex.data();
body = fP->fKNotes->text(fP->fIndex.key());
if (body.startsWith(title))
@@ -517,7 +517,7 @@ bool KNotesAction::deleteNoteOnPilot()
FUNCTIONSETUP;
/*
- QValueList<NoteAndMemo>::Iterator i = fP->fIdList.begin();
+ TQValueList<NoteAndMemo>::Iterator i = fP->fIdList.begin();
while ( i != fP->fIdList.end() )
{
// TODO DCOP_REMOVE
@@ -732,7 +732,7 @@ int KNotesAction::addNoteToPilot()
<< endl;
#endif
- QString text = j->summary() + CSL1("\n");
+ TQString text = j->summary() + CSL1("\n");
text.append( j->description() );
//TODO DCOP_REMOVAL
//text.append(fP->fKNotes->text(fP->fIndex.key()));
@@ -775,10 +775,10 @@ void KNotesAction::cleanupMemos()
<< endl;
#endif
- QValueList<KNoteID_t> notes;
- QValueList<int> memos;
+ TQValueList<KNoteID_t> notes;
+ TQValueList<int> memos;
- for (QValueList<NoteAndMemo>::ConstIterator i =
+ for (TQValueList<NoteAndMemo>::ConstIterator i =
fP->fIdList.begin();
i!=fP->fIdList.end();
++i)
@@ -846,7 +846,7 @@ void KNotesAction::cleanupMemos()
}
/* virtual */ QString KNotesAction::statusString() const
{
switch(fActionStatus)
{
@@ -846,7 +846,7 @@ void KNotesAction::cleanupMemos()
}
-/* virtual */ QString KNotesAction::statusString() const
+/* virtual */ TQString KNotesAction::statusString() const
{
switch(fActionStatus)